Function print_errors
pub fn print_errors(errors: &[CompileError], source: &str, filename: &str)Expand description
Render to stderr with color, used by the CLI.
pub fn print_errors(errors: &[CompileError], source: &str, filename: &str)Render to stderr with color, used by the CLI.